California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 030 - PROVIDES FUNDING FOR PROGRAMS TO REDUCE GREENHOUSE GAS EMISSIONS BY INCREASING TAX ON PERSONAL INCOME OVER $2 MILLION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1450340 | NO ON 30 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1444991 | CALIFORNIA ENVIRONMENTAL VOTERS ISSUES COMMITTEE - YES ON 30 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1449331 | YES ON 30: WORKING FAMILIES AND ENVIRONMENTAL VOTERS TO EXPOSE GREEDY BILLIONAIRES AND CEOS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1443818 | YES ON 30: CLEAN AIR CALIFORNIA, A COALITION OF STATE FIREFIGHTERS, WORKING FAMILIES, RIDESHARE COMPANIES, AND ENVIRONMENTAL GROUPS | SUPPORT